var prefs = (function () {
    'use strict';

    const ExtensionUtils = imports.misc.extensionUtils;
    const Me = ExtensionUtils.getCurrentExtension();
    const Gio = imports.gi.Gio;
    class FocusSettings {
        constructor(settings) {
            this.settings = settings;
        }
        get focus_opacity() {
            return this.settings.get_uint('focus-opacity');
        }
        set_focus_opacity(val) {
            this.settings.set_uint('focus-opacity', val);
        }
        get special_focus_opacity() {
            return this.settings.get_uint('special-focus-opacity');
        }
        set_special_focus_opacity(val) {
            this.settings.set_uint('special-focus-opacity', val);
        }
        get inactive_opacity() {
            return this.settings.get_uint('inactive-opacity');
        }
        set_inactive_opacity(val) {
            this.settings.set_uint('inactive-opacity', val);
        }
    }
    function get_settings() {
        var _a;
        const schema = Gio.SettingsSchemaSource.new_from_directory(Me.dir.get_child('schemas').get_path(), Gio.SettingsSchemaSource.get_default(), false);
        return new FocusSettings(new Gio.Settings({
            settings_schema: (_a = schema.lookup('org.gnome.shell.extensions.focus', true)) !== null && _a !== void 0 ? _a : undefined,
        }));
    }

    const ExtensionUtils$1 = imports.misc.extensionUtils;
    const Me$1 = ExtensionUtils$1.getCurrentExtension();
    const Gio$1 = imports.gi.Gio;
    const Gtk = imports.gi.Gtk;
    function init() { }
    function buildPrefsWidget() {
        const settings = get_settings();
        const widget = new Gtk.Grid({
            margin: 18,
            column_spacing: 12,
            row_spacing: 12,
            visible: true,
        });
        const title = new Gtk.Label({
            label: '<b>' + Me$1.metadata.name + ' Extension Preferences</b>',
            halign: Gtk.Align.START,
            use_markup: true,
            visible: true,
        });
        widget.attach(title, 0, 0, 2, 1);
        const focus_opacity_label = new Gtk.Label({
            label: 'Focus Opacity',
            halign: Gtk.Align.START,
            visible: true,
        });
        const focus_opacity_entry = new Gtk.Entry({
            input_purpose: Gtk.InputPurpose.NUMBER,
            visible: true,
        });
        focus_opacity_entry.set_text(settings.focus_opacity.toString());
        focus_opacity_entry.connect('changed', function () {
            const value = parseInt(focus_opacity_entry.text);
            if (!isNaN(value) && value <= 100 && value >= 0) {
                settings.set_focus_opacity(value);
                Gio$1.Settings.sync();
            }
        });
        widget.attach(focus_opacity_label, 0, 1, 1, 1);
        widget.attach(focus_opacity_entry, 1, 1, 1, 1);
        const inactive_opacity_label = new Gtk.Label({
            label: 'Inactive Opacity',
            halign: Gtk.Align.START,
            visible: true,
        });
        const inactive_opacity_entry = new Gtk.Entry({
            input_purpose: Gtk.InputPurpose.NUMBER,
            visible: true,
        });
        inactive_opacity_entry.set_text(settings.inactive_opacity.toString());
        inactive_opacity_entry.connect('changed', function () {
            const value = parseInt(inactive_opacity_entry.text);
            if (!isNaN(value) && value <= 100 && value >= 0) {
                settings.set_inactive_opacity(value);
                Gio$1.Settings.sync();
            }
        });
        widget.attach(inactive_opacity_label, 0, 2, 1, 1);
        widget.attach(inactive_opacity_entry, 1, 2, 1, 1);
        const special_focus_opacity_label = new Gtk.Label({
            label: 'Special Focus Opacity',
            halign: Gtk.Align.START,
            visible: true,
        });
        const special_focus_opacity_entry = new Gtk.Entry({
            input_purpose: Gtk.InputPurpose.NUMBER,
            visible: true,
        });
        special_focus_opacity_entry.set_text(settings.special_focus_opacity.toString());
        special_focus_opacity_entry.connect('changed', function () {
            const value = parseInt(special_focus_opacity_entry.text);
            if (!isNaN(value) && value <= 100 && value >= 0) {
                settings.set_special_focus_opacity(value);
                Gio$1.Settings.sync();
            }
        });
        widget.attach(special_focus_opacity_label, 0, 3, 1, 1);
        widget.attach(special_focus_opacity_entry, 1, 3, 1, 1);
        return widget;
    }
    var prefs = {
        init,
        buildPrefsWidget,
    };

    return prefs;

}());
var init = prefs.init;
var buildPrefsWidget = prefs.buildPrefsWidget;
